==> jc-1.4.0.tar.gz: java/rmi/server/ObjID.h <==
// public final class java.rmi.server.ObjID

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2e03d15cf75b7ba3 java_rmi_server_ObjID

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_rmi_server_ObjID_H_
#define _JC_java_rmi_server_ObjID_H_

// Forward structure declarations
struct _jc_java_io_ObjectInput$object;
struct _jc_java_io_ObjectOutput$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_rmi_server_ObjID$object;
struct _jc_java_rmi_server_UID$object;

// Typedefs
typedef struct _jc_java_rmi_server_ObjID$sub_refs	_jc_java_rmi_server_ObjID$sub_refs;
typedef struct _jc_java_rmi_server_ObjID$sub_nonrefs	_jc_java_rmi_server_ObjID$sub_nonrefs;
typedef struct _jc_java_rmi_server_ObjID$refs	_jc_java_rmi_server_ObjID$refs;
typedef struct _jc_java_rmi_server_ObjID$nonrefs	_jc_java_rmi_server_ObjID$nonrefs;
typedef struct _jc_java_rmi_server_ObjID$object	_jc_java_rmi_server_ObjID$object;

typedef struct _jc_java_rmi_server_ObjID$fields_struct	_jc_java_rmi_server_ObjID$fields_struct;
typedef const struct _jc_java_rmi_server_ObjID$vmethods	_jc_java_rmi_server_ObjID$vmethods;
typedef const struct _jc_java_rmi_server_ObjID$vtable	_jc_java_rmi_server_ObjID$vtable;
typedef const struct _jc_java_rmi_server_ObjID$vtype	_jc_java_rmi_server_ObjID$vtype;

// Class fields structure
struct _jc_java_rmi_server_ObjID$fields_struct {
	struct _jc_java_lang_Class$object	*class__24java__24rmi__24server__24ObjID;
	struct _jc_java_lang_Object$object	*lock;
	jlong	next;
	jlong	serialVersionUID;
	jint	ACTIVATOR__5fID;
	jint	DGC__5fID;
	jint	REGISTRY__5fID;
};
extern _jc_java_rmi_server_ObjID$fields_struct _jc_java_rmi_server_ObjID$class_fields;

// Constructors
extern void _jc_java_rmi_server_ObjID$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_rmi_server_ObjID$object *);
extern void _jc_java_rmi_server_ObjID$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_rmi_server_ObjID$object *, jint);

// Virtual methods
extern jboolean _jc_java_rmi_server_ObjID$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_rmi_server_ObjID$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_java_rmi_server_ObjID$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_rmi_server_ObjID$object *);
extern struct _jc_java_lang_String$object *_jc_java_rmi_server_ObjID$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_rmi_server_ObjID$object *);
extern void _jc_java_rmi_server_ObjID$method$write$da818bd06a3b1314(_jc_env *, struct _jc_java_rmi_server_ObjID$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_java_rmi_server_ObjID$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_rmi_server_ObjID$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_rmi_server_ObjID$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_java_rmi_server_ObjID$method_info$write$da818bd06a3b1314;

// Static methods
extern void _jc_java_rmi_server_ObjID$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_lang_Class$object *_jc_java_rmi_server_ObjID$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);
extern struct _jc_java_rmi_server_ObjID$object *_jc_java_rmi_server_ObjID$method$read$82602aed6d4a8314(_jc_env *, struct _jc_object *);

// Virtual methods structure
struct _jc_java_rmi_server_ObjID$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_rmi_server_ObjID$object *, struct _jc_java_lang_Object$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_rmi_server_ObjID$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_rmi_server_ObjID$object *);
	void	(*write$da818bd06a3b1314)(_jc_env *, struct _jc_java_rmi_server_ObjID$object *, struct _jc_object *);
};

// Vtable
struct _jc_java_rmi_server_ObjID$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_rmi_server_ObjID$vmethods	java_rmi_server_ObjID;
};

// Vtype
struct _jc_java_rmi_server_ObjID$vtype {
	_jc_type			type;
	_jc_java_rmi_server_ObjID$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_server_ObjID$sub_refs {
	struct _jc_java_rmi_server_UID$object	*space;
};

// Reference instance fields (object)
struct _jc_java_rmi_server_ObjID$refs {
    _jc_java_rmi_server_ObjID$sub_refs	java_rmi_server_ObjID;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_server_ObjID$sub_nonrefs {
	jlong	objNum;
};

// Non-reference instance fields (object)
struct _jc_java_rmi_server_ObjID$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_rmi_server_ObjID$sub_nonrefs	java_rmi_server_ObjID;
};

// Object instance structure
struct _jc_java_rmi_server_ObjID$object {
	_jc_java_rmi_server_ObjID$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_server_ObjID$vtype	*vtype;
	_jc_java_rmi_server_ObjID$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_server_ObjID$vtype _jc_java_rmi_server_ObjID$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_server_ObjID, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_server_ObjID$class_object;

#endif	/* _JC_java_rmi_server_ObjID_H_ */

==> jc-1.4.6.tar.gz: java/rmi/server/ObjID.h <==
// public final class java.rmi.server.ObjID

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2e03d15cf75b7ba3 java_rmi_server_ObjID

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_rmi_server_ObjID_H_
#define _JC_java_rmi_server_ObjID_H_

// Forward structure declarations
struct _jc_java_io_ObjectInput$object;
struct _jc_java_io_ObjectOutput$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_rmi_server_ObjID$object;
struct _jc_java_rmi_server_UID$object;

// Typedefs
typedef struct _jc_java_rmi_server_ObjID$sub_refs	_jc_java_rmi_server_ObjID$sub_refs;
typedef struct _jc_java_rmi_server_ObjID$sub_nonrefs	_jc_java_rmi_server_ObjID$sub_nonrefs;
typedef struct _jc_java_rmi_server_ObjID$refs	_jc_java_rmi_server_ObjID$refs;
typedef struct _jc_java_rmi_server_ObjID$nonrefs	_jc_java_rmi_server_ObjID$nonrefs;
typedef struct _jc_java_rmi_server_ObjID$object	_jc_java_rmi_server_ObjID$object;

typedef struct _jc_java_rmi_server_ObjID$fields_struct	_jc_java_rmi_server_ObjID$fields_struct;
typedef const struct _jc_java_rmi_server_ObjID$vmethods	_jc_java_rmi_server_ObjID$vmethods;
typedef const struct _jc_java_rmi_server_ObjID$vtable	_jc_java_rmi_server_ObjID$vtable;
typedef const struct _jc_java_rmi_server_ObjID$vtype	_jc_java_rmi_server_ObjID$vtype;

// Class fields structure
struct _jc_java_rmi_server_ObjID$fields_struct {
	struct _jc_java_lang_Class$object	*class__24java__24rmi__24server__24ObjID;
	struct _jc_java_lang_Object$object	*lock;
	jlong	next;
	jlong	serialVersionUID;
	jint	ACTIVATOR__5fID;
	jint	DGC__5fID;
	jint	REGISTRY__5fID;
};
extern _jc_java_rmi_server_ObjID$fields_struct _jc_java_rmi_server_ObjID$class_fields;

// Constructors
extern void _jc_java_rmi_server_ObjID$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_rmi_server_ObjID$object *) _JC_JCNI_ATTR;
extern void _jc_java_rmi_server_ObjID$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_rmi_server_ObjID$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_rmi_server_ObjID$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_rmi_server_ObjID$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_java_rmi_server_ObjID$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_rmi_server_ObjID$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_rmi_server_ObjID$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_rmi_server_ObjID$object *) _JC_JCNI_ATTR;
extern void _jc_java_rmi_server_ObjID$method$write$da818bd06a3b1314(_jc_env *, struct _jc_java_rmi_server_ObjID$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_rmi_server_ObjID$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_rmi_server_ObjID$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_rmi_server_ObjID$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_java_rmi_server_ObjID$method_info$write$da818bd06a3b1314;

// Static methods
extern void _jc_java_rmi_server_ObjID$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_java_rmi_server_ObjID$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;
extern struct _jc_java_rmi_server_ObjID$object *_jc_java_rmi_server_ObjID$method$read$82602aed6d4a8314(_jc_env *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_rmi_server_ObjID$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_rmi_server_ObjID$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_rmi_server_ObjID$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_rmi_server_ObjID$object *) _JC_JCNI_ATTR;
	void	(*write$da818bd06a3b1314)(_jc_env *, struct _jc_java_rmi_server_ObjID$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_rmi_server_ObjID$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_rmi_server_ObjID$vmethods	java_rmi_server_ObjID;
};

// Vtype
struct _jc_java_rmi_server_ObjID$vtype {
	_jc_type			type;
	_jc_java_rmi_server_ObjID$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_server_ObjID$sub_refs {
	struct _jc_java_rmi_server_UID$object	*space;
};

// Reference instance fields (object)
struct _jc_java_rmi_server_ObjID$refs {
    _jc_java_rmi_server_ObjID$sub_refs	java_rmi_server_ObjID;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_server_ObjID$sub_nonrefs {
	jlong	objNum;
};

// Non-reference instance fields (object)
struct _jc_java_rmi_server_ObjID$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_rmi_server_ObjID$sub_nonrefs	java_rmi_server_ObjID;
};

// Object instance structure
struct _jc_java_rmi_server_ObjID$object {
	_jc_java_rmi_server_ObjID$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_server_ObjID$vtype	*vtype;
	_jc_java_rmi_server_ObjID$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_server_ObjID$vtype _jc_java_rmi_server_ObjID$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_server_ObjID, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_server_ObjID$class_object;

#endif	/* _JC_java_rmi_server_ObjID_H_ */
